# Function 5 This function is not used by FLS5. Arguments on stack: _cvt, ppem1, ppem2_

Assembly |  | Stack
--- | --- | ---
PUSHW[ ] | 1 value pushed
5 | function index
FDEF[ ] | FunctionDefinition
MPPEM[ ] | MeasurePixelPerEm | cvt ppem1 ppem2 ppem
DUP[ ] | DuplicateTopStack | cvt ppem1 ppem2 ppem ppem
PUSHB[ ] | 1 value pushed
3 |  | cvt ppem1 ppem2 ppem ppem 3
MINDEX[ ] | MoveXToTopStack | cvt ppem1 ppem ppem ppem2
LT[ ] | LessThan | cvt ppem1 ppem ppem<ppem2
IF[ ] | If | cvt ppem1 ppem
LTEQ[ ] | LessThenOrEqual | cvt ppem1<=ppem
IF[ ] | If | cvt
PUSHB[ ] | 1 value pushed
128 |  | cvt 128
WCVTP[ ] | WriteCVTInPixels | —
ELSE[ ] | Else | cvt
PUSHB[ ] | 1 value pushed
64 |  | cvt 64
WCVTP[ ] | WriteCVTInPixels | —
EIF[ ] | EndIf | —
ELSE[ ] | Else | cvt ppem1 ppem
POP[ ] | PopTopStack | cvt ppem1
POP[ ] | PopTopStack | cvt
DUP[ ] | DuplicateTopStack | cvt cvt
RCVT[ ] | ReadCVT | cvt z
PUSHB[ ] | 1 value pushed
192 |  | cvt z 192
LT[ ] | LessThan | cvt z<192
IF[ ] | If | cvt
PUSHB[ ] | 1 value pushed
192 |  | cvt 192
WCVTP[ ] | WriteCVTInPixels | —
ELSE[ ] | Else | cvt
POP[ ] | PopTopStack | —
EIF[ ] | EndIf
EIF[ ] | EndIf
ENDF[ ] | EndFunctionDefinition